"""
This file is NOT auto-generated
"""

from audio.ttypes import *
from communication.ttypes import *
from discourse.ttypes import *
from email.ttypes import *
from entities.ttypes import *
from language.ttypes import *
from metadata.ttypes import *
from nitf.ttypes import *
from situations.ttypes import *
from spans.ttypes import *
from structure.ttypes import *
from twitter.ttypes import *
from uuid.ttypes import *
